# This file was auto-generated by Fern from our API Definition.

import enum


class AthenaEnvironment(enum.Enum):
    PRODUCTION = "https://api.athenaintel.com"
    STAGING = "https://staging-api.athenaintel.com"
